%global __python3 /usr/bin/python3.10
%define anolis_release 1
%bcond_with tests

%global pybasever 3.10

%global srcname setuptools
%global python_wheel_name %{srcname}-%{version}-py3-none-any.whl

%bcond_without bootstrap

Name:           python%{pybasever}-setuptools
Version:        68.0.0
Release:        %{anolis_release}%{?dist}
Summary:        Easily build and distribute Python packages

License:        MIT and ASL 2.0 and (BSD or ASL 2.0) and Python
URL:            https://pypi.python.org/pypi/%{srcname}
Source0:        %{pypi_source %{srcname} %{version}}

BuildArch:       noarch
BuildRequires:   python%{pybasever}-devel
%if %{without bootstrap}
BuildRequires:   pyproject-rpm-macros >= 0-44
BuildRequires:   python%{pybasever}-setuptools
BuildRequires:   python3-rpm-generators >= 11-8
%endif
%if %{with tests}
BuildRequires:   gcc
BuildRequires:   python%{pybasever}-pytest
%endif

%description
Setuptools is a collection of enhancements to the Python %{pybasever} distutils that allow
you to more easily build and distribute Python packages, especially ones that
have dependencies on other packages.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.


%global bundled %{expand:
Provides: bundled(python%{pybasever}dist(appdirs)) = 1.4.3
Provides: bundled(python%{pybasever}dist(importlib-metadata)) = 4.11.1
Provides: bundled(python%{pybasever}dist(importlib-resources)) = 5.4
Provides: bundled(python%{pybasever}dist(jaraco-text)) = 3.7
Provides: bundled(python%{pybasever}dist(more-itertools)) = 8.8
Provides: bundled(python%{pybasever}dist(ordered-set)) = 3.1.1
Provides: bundled(python%{pybasever}dist(packaging)) = 21.3
Provides: bundled(python%{pybasever}dist(pyparsing)) = 2.2.1
Provides: bundled(python%{pybasever}dist(typing-extensions)) = 4.0.1
Provides: bundled(python%{pybasever}dist(zipp)) = 3.7
}

%{bundled}

%py_provides    python%{pybasever}-pkg_resources
%py_provides    python%{pybasever}-pkg-resources

%description -n python%{pybasever}-setuptools
Setuptools is a collection of enhancements to the Python 3.10 distutils that allow
you to more easily build and distribute Python 3.10 packages, especially ones that
have dependencies on other packages.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.


%if %{without bootstrap}
%package -n     %{python_wheel_pkg_prefix}-%{srcname}-wheel
Summary:        The setuptools wheel
%{bundled}

%description -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
A Python wheel of setuptools to use with venv.
%endif

%package -n     python%{pybasever}-setuptools-doc
Summary:        doc files for python%{pybasever}-setuptools
Requires:       python%{pybasever}-setuptools = %{version}-%{release}

%description -n python%{pybasever}-setuptools-doc
doc files for python%{pybasever}-setuptools.

%prep
%autosetup -p1 -n %{srcname}-%{version}

find setuptools pkg_resources -name \*.py | xargs sed -i -e '1 {/^#!\//d}'
rm -f setuptools/*.exe
rm -r docs/conf.py

%build
%if %{without bootstrap}
%py3_build_wheel
%else
%{__python3} setup.py build
%endif

%install
%if %{without bootstrap}
%py3_install_wheel %{python_wheel_name}
%else
%{__python3} setup.py install --root=%{buildroot}
%endif

rm -rf %{buildroot}%{python3_sitelib}/pkg_resources/tests/
%if %{without bootstrap}
sed -i '/\/pkg_resources\/tests\b/d' %{pyproject_files}
%endif

%if %{without bootstrap}
mkdir -p %{buildroot}%{python_wheel_dir}
install -p %{_pyproject_wheeldir}/%{python_wheel_name} -t %{buildroot}%{python_wheel_dir}
%endif

%if %{with tests}
%check
cat pkg_resources/_vendor/vendored.txt setuptools/_vendor/vendored.txt > allvendor.txt
%{_rpmconfigdir}/pythonbundles.py allvendor.txt --namespace 'python%{pybasever}dist' --compare-with '%{bundled}'

test $(du %{_pyproject_wheeldir}/%{python_wheel_name} | cut -f1) -lt 800

test ! -d %{buildroot}%{python3_sitelib}/pkg_resources/tests
test ! -d %{buildroot}%{python3_sitelib}/setuptools/tests

rm pyproject.toml

PRE_BUILT_SETUPTOOLS_WHEEL=%{_pyproject_wheeldir}/%{python_wheel_name} \
PYTHONPATH=$(pwd) %pytest \
 --ignore=setuptools/tests/test_integration.py \
 --ignore=setuptools/tests/integration/ \
 --ignore=setuptools/tests/test_develop.py \
 -k "not test_pip_upgrade_from_source"
%endif

%files -n python%{pybasever}-setuptools 
%license LICENSE
%doc docs/*
%{python3_sitelib}/distutils-precedence.pth
%{python3_sitelib}/pkg_resources/
%{python3_sitelib}/setuptools*/
%{python3_sitelib}/_distutils_hack/

%if %{without bootstrap}
%files -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
%license LICENSE
# we own the dir for simplicity
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{python_wheel_name}
%endif

%files -n python%{pybasever}-setuptools-doc
%doc CHANGES.rst README.rst

%changelog
* Mon Oct 21 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 68.0.0-1
- Init for 3.10
